from django.conf.urls import patterns, include, url
from django.contrib import admin

admin.autodiscover()

urlpatterns = patterns("",
    ("^admin/", include(admin.site.urls)),
    # HOMEPAGE AS STATIC TEMPLATE
    #url("^$", direct_to_template, {"template": "index.html"}, name="home"),
    # HOMEPAGE AS AN EDITABLE PAGE IN THE PAGE TREE
    url("^$", "mezzanine.pages.views.page", {"slug": "/"}, name="home"),
    # MEZZANINE'S URLS
    ("^", include("mezzanine.urls")),

)





###################
# DEPLOY SETTINGS #
###################

# These settings are used by the default fabfile.py provided.
# Check fabfile.py for defaults.

# FABRIC = {
#     "SSH_USER": "", # SSH username
#     "SSH_PASS":  "", # SSH password (consider key-based authentication)
#     "SSH_KEY_PATH":  "", # Local path to SSH key file, for key-based auth
#     "HOSTS": [], # List of hosts to deploy to
#     "VIRTUALENV_HOME":  "", # Absolute remote path for virtualenvs
#     "PROJECT_NAME": "", # Unique identifier for project
#     "REQUIREMENTS_PATH": "", # Path to pip requirements, relative to project
#     "GUNICORN_PORT": 8000, # Port gunicorn will listen on
#     "LOCALE": "en_US.UTF-8", # Should end with ".UTF-8"
#     "LIVE_HOSTNAME": "www.example.com", # Host for public site.
#     "REPO_URL": "", # Git or Mercurial remote repo URL for the project
#     "DB_PASS": "", # Live database password
#     "ADMIN_PASS": "", # Live admin user password
# }




""" local.settings
This is where you set your own localizations
for a specific instance of a Backstage project.

Any valid django settings which are set here will
over-ride Backstage and Django defaults.  Any other variables you set here
will also be set in your project's Settings namespace as well

#
*Some* of the Settings you'll most likely wish to set here include
DATABASES
STATIC_URL
MEDIA_URL
DEBUG
TEMPLATE_DEBUG

You can modify without replacing any list-type setting (INSTALLED_APPS, TEMPLATE_DIRS, etc) by
using the proper list.insert(0,'blah') or list.append('blah') syntax as in
INSTALLED_APPS.append('my.awesome.app')
"""



ALLOWED_HOSTS = []

CACHES = {
    'default': {
        'BACKEND': 'django.core.cache.backends.dummy.DummyCache',
    }
}

SECRET_KEY=''

TEMPLATE_DIRS = []
TEMPLATE_LOADERS = [
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
]

MIDDLEWARE_CLASSES = [
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',   
    'django.middleware.common.CommonMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'debug_toolbar.middleware.DebugToolbarMiddleware',
]

TEMPLATE_CONTEXT_PROCESSORS = [
    'django.contrib.auth.context_processors.auth',
    'django.contrib.messages.context_processors.messages',
    'django.core.context_processors.debug',
    'django.core.context_processors.i18n',
    'django.core.context_processors.media',
    'django.core.context_processors.static',
    'django.core.context_processors.request',
    'django.core.context_processors.tz',
    'sekizai.context_processors.sekizai',
    ]

STATICFILES_FINDERS = ["django.contrib.staticfiles.finders.FileSystemFinder",
 "django.contrib.staticfiles.finders.AppDirectoriesFinder",
 "compressor.finders.CompressorFinder",]

AUTHENTICATION_BACKENDS =  [ 'django.contrib.auth.backends.ModelBackend',]

try:
    DEBUG_TOOLBAR_CONFIG['INTERCEPT_REDIRECTS'] = False
except:
    DEBUG_TOOLBAR_CONFIG = {}
    DEBUG_TOOLBAR_CONFIG['INTERCEPT_REDIRECTS'] = False




from setuptools import setup, find_packages

setup(
    name='django_backstage',
    version='0.0.5.1',
    description='Django project and site deployment using uWSGI, nginx, etc.',
    author='MiddleFork',
    author_email='walker@mfgis.com',
    packages=find_packages(),
    install_requires=['django==1.5.5', ],
    )



from django.http import Http404,HttpResponse
from django.template import loader, Context, RequestContext
from django.shortcuts import render_to_response as r2r
def getContext(request,obj):
    context=RequestContext(request,{'obj':obj,})
    instance = RequestContext(request)
    return context,instance

def renderContext(request,obj,template):
    if repr(obj).split(' ')[1] == 'NullObj':
        raise Http404
    try:
        context=RequestContext(request,{'obj':obj,})
        instance = RequestContext(request)
        return r2r(template,context,context_instance=instance)
    except:
        raise


        


